function _createForOfIteratorHelper(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (!it) {
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;
      var F = function F() {};
      return {
        s: F,
        n: function n() {
          if (i >= o.length) return {
            done: true
          };
          return {
            done: false,
            value: o[i++]
          };
        },
        e: function e(_e) {
          throw _e;
        },
        f: F
      };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var normalCompletion = true,
    didErr = false,
    err;
  return {
    s: function s() {
      it = it.call(o);
    },
    n: function n() {
      var step = it.next();
      normalCompletion = step.done;
      return step;
    },
    e: function e(_e2) {
      didErr = true;
      err = _e2;
    },
    f: function f() {
      try {
        if (!normalCompletion && it["return"] != null) it["return"]();
      } finally {
        if (didErr) throw err;
      }
    }
  };
}
function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) {
    arr2[i] = arr[i];
  }
  return arr2;
}
/* WooCommerce Step Filter global instance and main event handlers
 * Original author: mail@troll-winner.ru
 * Further changes, comments: mail@troll-winner.ru
 */

import { WCSF } from 'wcsf';
var wcsf = {
  windowNode: window,
  documentNode: document,
  stickyObserverElements: null,
  init: function init() {
    if (typeof WCSF === 'undefined') {
      this.windowNode.console.error('WCSF class is not exist');
      return this;
    }
    var _iterator = _createForOfIteratorHelper(this.documentNode.querySelectorAll('[data-component~="wcsf"]')),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var element = _step.value;
        element.wcsf = new WCSF(element, JSON.parse(element.getAttribute('data-options')) || {});
        element.wcsf.init();
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return this;
  },
  tooltip: function () {
    var hideTimeout = null;
    return {
      template: '<span class="wcsf-tooltip" data-component="wcsf-tooltip" role="tooltip" aria-hidden="false">%text%</span>',
      // eslint-disable-line
      fadeDuration: 200,
      hideDelay: 2500,
      hideAll: function hideAll() {
        var _iterator2 = _createForOfIteratorHelper(wcsf.documentNode.querySelectorAll('[data-component~="wcsf-tooltip"]')),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var element = _step2.value;
            this.hide(element);
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
        return this;
      },
      hide: function hide(element) {
        if (!element) {
          return this;
        }
        element.style.transition = wcsf.fadeDuration + 'ms';
        element.style.opacity = 0;
        setTimeout(function () {
          return element.remove();
        }, this.fadeDuration);
        return this;
      },
      show: function show(element, text) {
        var _this = this;
        this.hideAll();
        clearTimeout(hideTimeout);
        var tooltip = wcsf.documentNode.createElement('span');
        tooltip.innerHTML = this.template.replace('%text%', text);
        tooltip = tooltip.querySelector(':first-child');
        element.before(tooltip);
        hideTimeout = setTimeout(function () {
          return _this.hide(tooltip);
        }, this.hideDelay);
        return this;
      }
    };
  }(),
  updateStickyObserverElementsState: function updateStickyObserverElementsState() {
    if (!this.stickyObserverElements || this.stickyObserverElements.length <= 0) {
      return;
    }
    var _iterator3 = _createForOfIteratorHelper(this.stickyObserverElements),
      _step3;
    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var element = _step3.value;
        if (!element.parentElement) {
          continue;
        }
        var parentTop = element.parentElement.getBoundingClientRect().top;
        var top = Math.round(element.getBoundingClientRect().top - parentTop);
        element.style.position = 'static';
        element.toggleAttribute('stuck', top !== Math.round(element.getBoundingClientRect().top - parentTop));
        element.style.position = '';
        element.dataset.prevClientTop = String(top);
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
  }
};
wcsf.windowNode.addEventListener('load', function () {
  // init sticky observer elements
  wcsf.stickyObserverElements = wcsf.documentNode.querySelectorAll('[data-component~="wcsf-sticky-observer"]');
  if (!wcsf.stickyObserverElements || wcsf.stickyObserverElements.length <= 0) {
    return;
  }
  wcsf.updateStickyObserverElementsState();
  wcsf.windowNode.addEventListener('resize', function () {
    return setTimeout(function () {
      return wcsf.updateStickyObserverElementsState();
    }, 0);
  });
  wcsf.windowNode.addEventListener('scroll', function () {
    var _iterator4 = _createForOfIteratorHelper(wcsf.stickyObserverElements),
      _step4;
    try {
      for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
        var element = _step4.value;
        if (!element.parentElement) {
          continue;
        }
        var top = Math.round(element.getBoundingClientRect().top - element.parentElement.getBoundingClientRect().top);
        element.toggleAttribute('stuck', Number(element.dataset.prevClientTop) !== top);
        element.dataset.prevClientTop = String(top);
      }
    } catch (err) {
      _iterator4.e(err);
    } finally {
      _iterator4.f();
    }
  }, false);
});

// init plugin
wcsf.documentNode.addEventListener('DOMContentLoaded', function () {
  return wcsf.init();
});
wcsf.documentNode.addEventListener('init.wcsf', function () {
  return wcsf.init();
});

// get preliminary results count manual trigger
wcsf.documentNode.addEventListener('getPreliminaryResultsCount.wcsf', function (event) {
  if (event.detail.data && event.detail.data.tooltip) {
    wcsf.tooltip.show(event.detail.element, event.detail.data.tooltip);
  }
});

// ajax event is completed
wcsf.documentNode.addEventListener('ajaxCompleted.wcsf', function (event) {
  var instance = event.detail.instance;

  // re-init sticky observer elements
  wcsf.stickyObserverElements = instance.element.querySelectorAll('[data-component~="wcsf-sticky-observer"]');
  wcsf.updateStickyObserverElementsState();

  // noUi slider init
  wcsf.documentNode.dispatchEvent(new CustomEvent('init.nouislider.wcsf'));
  if (event.detail.response.hasError) {
    var message = instance.element.querySelectorAll('[data-component~="wcsf-message"]');

    // scroll to the message
    if (message && !instance.isScrolledIntoView(message)) {
      instance.scrollToElement(message, instance.options.scrollingUpGap);
    }

    // vibration signal
    instance.vibrate();
  }
});

// hide tooltips on click
wcsf.documentNode.addEventListener('click', function () {
  return wcsf.tooltip.hideAll();
});

// contact form 7 hooks
if (typeof wpcf7 !== 'undefined') {
  wcsf.documentNode.addEventListener('ajaxCompleted.wcsf', function (event) {
    var form = event.detail.instance.element.querySelector('.wpcf7-form');
    if (form) {
      if (typeof wpcf7.initForm !== 'undefined') {
        wpcf7.initForm($(form));
      } else if (typeof wpcf7.init !== 'undefined') {
        wpcf7.init(form);
      }
    }
  });
}
export default wcsf;