<?php
namespace WCStepFilter;

/**
 * Legacy Class
 *
 * @class Legacy
 * @version 1.2.0
 */
class Legacy
{
    public static $lastChangedVersion = '10.0.0';

    /** Class Constructor */
    public function __construct()
    {
        add_action('admin_footer', [$this, 'init']);
    }

    /** Init entities update */
    public function init()
    {
        $this->filtersUpdate();
    }

    /** Migrate filters meta */
    public function filtersUpdate()
    {
        $filters = get_posts([
            'numberposts' => -1,
            'fields' => 'ids',
            'post_type' => Filter::$postType
        ]);

        foreach ($filters as $filterId) {
            $filterId = (int) $filterId;

            // @since v9.0.0
            $keys = [
                '_sticky_header',
                '_sticky_footer',
                '_sticky_nav'
            ];

            foreach ($keys as $key) {
                $value = get_post_meta($filterId, $key, 1);

                if ($value == '0') {
                    update_post_meta($filterId, $key, 'never');
                } elseif ($value == '1') {
                    update_post_meta($filterId, $key, 'always');
                }
            }

            // @since v10.0.0
            $enabledControls = ['spacer'];
            $controls = [];
            $sorting = (array) get_post_meta($filterId, '_controls_sorting', 1);
            $keys = [
                '_show_controls_preliminary_results' => 'preliminary-results',
                '_enable_start_button' => 'start',
                '_enable_back_button' => 'back',
                '_enable_skip_button' => 'skip',
                '_enable_reset_button' => 'reset',
                '_show_next_button' => 'next',
                '_show_results_button' => 'results',
                '_show_results_pdf_button' => 'results-pdf'
            ];

            foreach ($keys as $key => $control) {
                $value = get_post_meta($filterId, $key, 1);

                if (filter_var($value, FILTER_VALIDATE_BOOL)
                    || in_array($value, ['on-answer', 'last-step', 'always', 'until-last-step'])
                ) {
                    $enabledControls[] = $control;
                }

                delete_post_meta($filterId, $key);
            }

            if (!empty($sorting)) {
                foreach ($sorting as $control) {
                    if (in_array($control, $enabledControls)) {
                        $controls[] = $control;
                    }
                }

                delete_post_meta($filterId, '_controls_sorting');
            } else {
                $controls = $enabledControls;
            }

            if (!empty($controls)) {
                update_post_meta($filterId, '_header_controls', $controls);
                update_post_meta($filterId, '_footer_controls', $controls);
            }

            // shop controls
            $enabledControls = [];
            $keys = [
                '_enable_shop_reset_button' => 'reset',
                '_enable_shop_back_button' => 'back',
                '_enable_shop_repeat_button' => 'repeat'
            ];

            foreach ($keys as $key => $control) {
                $value = get_post_meta($filterId, $key, 1);

                if (filter_var($value, FILTER_VALIDATE_BOOL)) {
                    $enabledControls[] = $control;
                }

                delete_post_meta($filterId, $key);
            }

            if (!empty($enabledControls)) {
                update_post_meta($filterId, '_shop_controls', $enabledControls);
            }
        }
    }
}
