<?php
namespace WCStepFilter\Product;

use WCStepFilter\L10N;
use WCStepFilter\TaxonomyTrait;
use WCStepFilter\TaxonomyInterface;
use WCStepFilter\Utils;

/**
 * Attribute Category Class
 *
 * @class Attribute
 * @version 1.0.0
 */
class Attribute implements TaxonomyInterface
{
    use TaxonomyTrait;

    /**
     * Taxonomy string
     * @var string
     */
    public static $taxonomy = 'product_tag';

    /**
     * Namespace string
     * @var string
     */
    public static $namespace = 'wcsf_product';

    /** Class Constructor */
    public function __construct()
    {
        add_action('woocommerce_after_register_post_type', [$this, 'init'], 1);
        add_action('wp_ajax_wcsfGetAttributeValuesSelectOptions', [$this, 'getValuesAjax']);
    }

    /** Register entity taxonomy */
    public function registerTaxonomy()
    {
        // already registered by WooCommerce
    }

    /**
     * Get product attribute settings model array
     *
     * @return array
     */
    public static function getCategorySettingsModel()
    {
        return apply_filters(
            'wcsf_attribute_value_settings_model',
            [
                'pre_checked' => [
                    'label' => L10N::r('Step Filter Pre-checked'),
                    'key' => '_wcsf_pre_checked',
                    'type' => 'checkbox',
                    'default' => false
                ],
                'thumbnail' => [
                    'label' => L10N::r('Step Filter Thumbnail'),
                    'key' => '_wcsf_thumbnail',
                    'type' => 'thumbnail',
                    'default' => ''
                ]
            ]
        );
    }

    public function init()
    {
        if (!function_exists('wc_get_attribute_taxonomies')) {
            return;
        }

        foreach (wc_get_attribute_taxonomies() as $attr) {
            add_action("pa_{$attr->attribute_name}_edit_form_fields", [$this, 'outputCategoryFields'], 10, 2);
            add_action("edited_pa_{$attr->attribute_name}", [$this, 'saveCategoryFields'], 10, 2);
            add_action("wp_ajax_woocommerce_json_search_pa_{$attr->attribute_name}", [$this, 'jsonSearch']);
        }
    }

    /** Search for terms and echo json */
    public function jsonSearch()
    {
        ob_start();
        check_ajax_referer('search-products', 'security');

        $attributes = wc_get_attribute_taxonomy_labels();
        $taxonomies = [];

        foreach ($attributes as $key => $name) {
            $taxonomies["pa_{$key}"] = $name;
        }

        $terms = get_terms([
            'taxonomy' => array_keys($taxonomies),
            'orderby' => 'id',
            'order' => 'ASC',
            'hide_empty' => false,
            'include' => !empty($_GET['include']) ? wp_parse_id_list($_GET['include']) : '',
            'exclude' => !empty($_GET['exclude']) ? wp_parse_id_list($_GET['exclude']) : '',
            'number' => !empty($_GET['limit']) ? intval($_GET['limit']) : '',
            'name__like' => $_GET['term']
        ]);

        $foundTerms = [];

        if (!empty($terms)) {
            foreach ($terms as $term) {
                $foundTerms[$term->term_id] = rawurldecode($taxonomies[$term->taxonomy] . ': ' . $term->name);
            }
        }

        Utils::sendJSON(apply_filters('woocommerce_json_search_found_attributes', $foundTerms));
    }

    /** Get list of an attribute values via Ajax */
    public function getValuesAjax()
    {
        $value = $_GET['value'];

        if (!$value) {
            Utils::sendJSON();
        }

        Utils::sendJSON(get_terms([
            'taxonomy' => "pa_{$value}",
            'hide_empty' => false,
            'fields' => 'id=>name'
        ]));
    }
}
