/* WooCommerce Step Filter App
 * Original author: Alex Troll
 * Further changes, comments: mail@troll-winner.com
 */

(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object' && typeof module !== 'undefined' && typeof require === 'function') {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const pluginName = 'wcsf';
    const defaults = {};
    const $document = $(document);

    const Plugin = function (element, options) {
        this.element = element;
        this.options = $.extend({}, defaults, options);

        return this.init();
    };

    /**
     * Init the instance
     * @returns {this} self instance
     */
    Plugin.prototype.init = function () {
        this.$element = $(this.element);
        this.$settings = this.$element.find('[data-component~="wcsf-setting"]');
        this.$source = this.$element.find('#_source');

        this.toggleFields();
        this.$element.on('change', '#_source', () => this.toggleFields());

        return this;
    };

    /**
     * Show/hide fields
     * @returns {this} self instance
     */
    Plugin.prototype.toggleFields = function () {
        const sourceType = this.$source.val();
        const sourceVisibilityRules = {
            questions: ['posts'],
            questions_categories: ['categories']
        };

        // toggle settings according to the selected source
        this.$settings.each(function () {
            const $element = $(this);

            if (!sourceVisibilityRules.hasOwnProperty($element.data('key'))) {
                return null;
            }

            const hide = $.inArray(sourceType, sourceVisibilityRules[$element.data('key')]) === -1;

            $element[hide ? 'addClass' : 'removeClass']('is-hidden-by-source');

            return this;
        });

        return this;
    };

    $.fn[pluginName] = function (options) {
        return this.each(function () {
            if (!$.data(this, pluginName)) {
                $.data(this, pluginName, new Plugin(this, options));
            }
        });
    };

    const init = () => $('[data-component~="wcsf-filter"]').each(function () {
        return $(this).wcsf();
    });

    $document.ready(() => init());
    $document.on('init.wcsf', () => init());
});
