/* WooCommerce Step Filter Sorting
 * Original author: Alex Troll
 * Further changes, comments: mail@troll-winner.com
 */

(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object' && typeof module !== 'undefined' && typeof require === 'function') {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const pluginName = 'wcsfSorting';
    const defaults = {};
    const $document = $(document);

    const Plugin = function (element, options) {
        this.element = element;
        this.options = $.extend({}, defaults, options);

        return this.init();
    };

    /**
     * Init the instance
     * @returns {this} self instance
     */
    Plugin.prototype.init = function () {
        this.$element = $(this.element);
        this.$list = this.$element.find('[data-component~="wcsf-sorting-list"]');
        this.$inputs = this.$element.find('[data-component~="wcsf-sorting-inputs"]');

        return this.initEventListeners();
    };

    /**
     * Add required event listeners
     * @returns {this} self instance
     */
    Plugin.prototype.initEventListeners = function () {
        // move item upper
        this.$element.on('click', '[data-component~="wcsf-sorting-move-up"]', (event) => {
            event.preventDefault();

            return this.moveItemUp();
        });

        // move item lower
        this.$element.on('click', '[data-component~="wcsf-sorting-move-down"]', (event) => {
            event.preventDefault();

            return this.moveItemDown();
        });

        return this;
    };

    /**
     * Move element upper in list
     * @returns {this} self instance
     */
    Plugin.prototype.moveItemUp = function () {
        this.$list
            .children(':selected')
            .each((i, selected) => {
                const $element = $(selected);
                const $input = this.$inputs.children(`[value="${$element.val()}"]`);

                if ($element.prev().length <= 0) {
                    return this;
                }

                $element.insertBefore($element.prev());
                $input.insertBefore($input.prev());

                return this;
            });

        this.$element.trigger('movedUp.item.sorting.wcsf', [this]);

        return this;
    };

    /**
     * Move element lower in list
     * @returns {this} self instance
     */
    Plugin.prototype.moveItemDown = function () {
        $(this.$list
            .children(':selected')
            .get()
            .reverse())
            .each((i, selected) => {
                const $element = $(selected);
                const $input = this.$inputs.children(`[value="${$element.val()}"]`);

                if ($element.next().length <= 0) {
                    return this;
                }

                $element.insertAfter($element.next());
                $input.insertAfter($input.next());

                return this;
            });

        this.$element.trigger('movedDown.item.sorting.wcsf', [this]);

        return this;
    };

    $.fn[pluginName] = function (options) {
        return this.each(function () {
            if (!$.data(this, pluginName)) {
                $.data(this, pluginName, new Plugin(this, options));
            }
        });
    };

    const init = () => $('[data-component~="wcsf-sorting"]').each(function () {
        return $(this).wcsfSorting();
    });

    $document.ready(() => init());
    $document.on('init.sorting.wcsf', () => init());
});
