<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'controls' => [],
    'activeStepId' => Filter::getActiveStepId($id),
    'canGoForward' => Filter::canGoForward($id),
    'canGoBack' => Filter::canGoBack($id),
    'filterValue' => Filter::getValue($id),
    'mode' => Filter::getSetting($id, 'mode'),
    'showNextButton' => Filter::getSetting($id, 'show_next_button'),
    'showResultsButton' => Filter::getSetting($id, 'show_results_button'),
    'showResultsPdfButton' => Filter::getSetting($id, 'show_results_pdf_button')
]);

$showResults = $arguments['showResultsButton'] == 'always'
    || ($arguments['showResultsButton'] == 'on-answer' && !empty($arguments['filterValue']))
    || ($arguments['showResultsButton'] == 'last-step' && !$arguments['canGoForward']);

$showResultsPDF = $arguments['showResultsPdfButton'] == 'always'
    || ($arguments['showResultsPdfButton'] == 'on-answer' && !empty($arguments['filterValue']))
    || ($arguments['showResultsPdfButton'] == 'last-step' && !$arguments['canGoForward']);

echo '<nav class="wcsf-controls">';

if ($arguments['mode'] == 'single-step') {
    // is single-step mode
    $availableControls = [
        'spacer' => true,
        'preliminary-results' => true,
        'reset' => !empty($arguments['filterValue']) || $arguments['canGoBack'],
        'results' => $showResults,
        'results-pdf' => $showResultsPDF
    ];
} elseif ($arguments['activeStepId'] == 'description') {
    // is the start step
    $availableControls = [
        'spacer' => true,
        'start' => true
    ];
} else {
    $availableControls = [
        'spacer' => true,
        'preliminary-results' => true,
        'back' => $arguments['canGoBack'],
        'skip' => $arguments['canGoForward'],
        'next' => ($arguments['showNextButton'] == 'until-last-step' && $arguments['canGoForward'])
            || $arguments['showNextButton'] == 'always',
        'reset' => !empty($arguments['filterValue']) || $arguments['canGoBack'],
        'results' => $showResults,
        'results-pdf' => $showResultsPDF
    ];
}

    foreach ($arguments['controls'] as $control) {
        $control = $control == 'spacer-2' ? 'spacer' : $control;

    if (!isset($availableControls[$control]) || !$availableControls[$control]) {
        continue;
    }

    Template::html('controls/' . $control, $arguments);
}

echo '</nav>';
