<?php
defined('ABSPATH') || exit;

use \WCStepFilter\Filter;
use \WCStepFilter\Question;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'formId' => null,
    'question' => null,
    'fields' => [],
    'showPreliminaryResultsCount' => Filter::getSetting($id, 'show_preliminary_results_count')
]);

$component = 'wcsf-field-input';
$actionOnClick = Question::getSetting($arguments['question']->id, 'action_on_click');

if ($actionOnClick == 'submit-and-go-next') {
    $component .= ' wcsf-submit-and-go-next';
} elseif ($actionOnClick == 'submit') {
    $component .= ' wcsf-submit';
} elseif ($arguments['showPreliminaryResultsCount']) {
    $component .= ' wcsf-get-preliminary-results-count';
}
?>
<div class="wcsf-field is-select form-group">
    <div class="input-group">
        <label for="wcsf-field-<?php echo esc_attr($arguments['question']->id); ?>"
            class="wcsf-field-label input-group-addon input-group-prepend input-group-text"><?php
            echo wp_kses_post($arguments['question']->name);
            ?></label>
        <select name="value[<?php echo esc_attr($arguments['question']->id); ?>][]"
            id="wcsf-field-<?php echo esc_attr($arguments['question']->id); ?>"
            class="form-control wcsf-field-input" required
            form="<?php echo esc_attr($arguments['formId']); ?>"
            data-component="<?php echo esc_attr($component); ?>">
            <?php foreach ($arguments['fields'] as $field) { ?>
                <option value="<?php echo esc_attr($field->value); ?>"<?php
                    selected($field->checked);
                    disabled($field->disabled);
                    ?>><?php
                    echo esc_html($field->name);

                    if (isset($field->count)) {
                        echo ' (' . esc_html($field->count) . ')';
                    }

                    if (isset($field->description) && !empty($field->description)) {
                        echo ' ' . esc_html($field->description);
                    }
                    ?></option>
            <?php } ?>
        </select>
    </div>
</div>
