<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;
use \WCStepFilter\Utils;

$arguments = Template::getHTMLArgs([
    'id' => $id,
    'formId' => 'wcsf-form-' . $id,
    'showHeader' => Filter::getSetting($id, 'show_header'),
    'showFooter' => Filter::getSetting($id, 'show_footer'),
    'mode' => Filter::getSetting($id, 'mode'),
    'activeStepId' => Filter::getActiveStepId($id),
    'nextButtonText' => Filter::getSetting($id, 'next_button_text'),
    'nextStepId' => Filter::getNextActiveStepId($id),
    'enableValue' => Filter::getSetting($id, 'enable_value'),
    'referer' => Utils::getCurrentURL(),
    'wizardArguments' => []
]);

$bodyTemplate = in_array($arguments['mode'], ['single-step', 'sequence']) ? 'single' : 'tabs';

if (!empty($arguments['wizardArguments']) && class_exists('\WCProductsWizard\Product')) {
    if (!isset($arguments['extraQueryArgs'])) {
        $arguments['extraQueryArgs'] = [];
    }

    $arguments['extraQueryArgs'] = array_replace_recursive(
        (array) $arguments['extraQueryArgs'],
        [
            'post__in' => \WCProductsWizard\Product::getStepProductsIds(
                $arguments['wizardArguments']['id'],
                $arguments['wizardArguments']['stepId']
            )
        ]
    );
}

do_action('wcsf_before_output', $arguments);
?>
<form hidden id="<?php echo esc_attr($arguments['formId']); ?>" action="?paged=1&wcsf-submit#"
    method="POST" data-component="wcsf-form" data-step-id="<?php echo esc_attr($arguments['activeStepId']); ?>">
    <input type="hidden" name="id" value="<?php echo esc_attr($arguments['id']); ?>">
    <input type="hidden" name="wcsf" value="<?php echo esc_attr($arguments['id']); ?>">
    <input type="hidden" name="stepId" value="<?php echo esc_attr($arguments['activeStepId']); ?>">
    <input type="hidden" name="referer" value="<?php echo esc_attr($arguments['referer']); ?>">
</form>
<section class="wcsf-form <?php echo 'is-step-' . esc_attr($arguments['activeStepId']); ?>"><?php
    if ($bodyTemplate == 'tabs') {
        Template::html('progress', $arguments);
        Template::html('nav/index', $arguments);
    }

    if ($arguments['showHeader']) {
        Template::html('header', $arguments);
    }

    if ($arguments['enableValue']) {
        Template::html('value', $arguments);
    }

    Template::html("body/${bodyTemplate}", $arguments);

    if ($arguments['showFooter']) {
        Template::html('footer', $arguments);
    }
    ?></section>
<?php do_action('wcsf_after_output', $arguments); ?>
