<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    return trigger_error('Empty filter id', E_USER_WARNING);
}

if (!get_post_status($id)) {
    return trigger_error('Filter does not exists', E_USER_WARNING);
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'id' => $id,
    'ajaxUrl' => admin_url('admin-ajax.php'),
    'filterByQueriedObject' => Filter::getSetting($id, 'filter_by_queried_object'),
    'scrollingTopOnUpdate' => Filter::getSetting($id, 'scrolling_top_on_update'),
    'scrollingUpGap' => Filter::getSetting($id, 'scrolling_up_gap'),
    'resetFilterOnShowing' => Filter::getSetting($id, 'reset_filter_on_showing')
]);

if ($arguments['filterByQueriedObject']) {
    $queriedObject = get_queried_object();

    if ($queriedObject && property_exists($queriedObject, 'taxonomy') && $queriedObject->taxonomy) {
        $arguments['extraQueryArgs']['tax_query'][] = [
            'taxonomy' => $queriedObject->taxonomy,
            'terms' => $queriedObject->term_id,
            'field' => 'id'
        ];
    }
}

do_action('wcsf_before', $arguments);
?>
<section class="wcsf <?php echo 'is-id-' . esc_attr($arguments['id']); ?>"
    data-component="wcsf" data-id="<?php echo esc_attr($arguments['id']); ?>"
    data-options="<?php echo esc_attr(wp_json_encode($arguments)); ?>"><?php
    Template::html('form', $arguments);
    ?></section>
<?php do_action('wcsf_after', $arguments); ?>
