<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs(
    [
        'id' => $id,
        'mode' => Filter::getSetting($id, 'mode'),
        'maxResultsNumber' => Filter::getSetting($id, 'max_results_number'),
        'resultsBeforeProductsDescription' => Filter::getSetting($id, 'results_before_products_description'),
        'resultsAfterProductsDescription' => Filter::getSetting($id, 'results_after_products_description'),
        'resultsBeforeNoProductsDescription' => Filter::getSetting($id, 'results_before_no_products_description'),
        'resultsAfterNoProductsDescription' => Filter::getSetting($id, 'results_after_no_products_description'),
        'wizardArguments' => [],
        'extraQueryArgs' => [
            'posts_per_page' => Filter::getSetting(
                $id,
                'results_within_products_per_page',
                wc_get_default_products_per_row() * wc_get_default_product_rows_per_page()
            ),
            'paged' => max(1, get_query_var('paged')),
            'orderby' => isset($_REQUEST['orderby'])
                ? wc_clean(wp_unslash($_REQUEST['orderby']))
                : apply_filters('woocommerce_default_catalog_orderby', get_option('woocommerce_default_catalog_orderby'))
        ]
    ],
    ['recursive' => true]
);

$productsQueryArgs = Filter::getProductsQueryArgs($id, $arguments['extraQueryArgs']);

if (!empty($arguments['wizardArguments']) && class_exists('\WCProductsWizard\Product')) {
    \WCProductsWizard\Product::request(array_replace_recursive($arguments['wizardArguments'], ['queryArgs' => $productsQueryArgs]));

    return;
}

$productsQuery = new WP_Query($productsQueryArgs);

do_action('wcsf_products_query', $id, $arguments, $productsQuery);

// change max products count
if ($arguments['maxResultsNumber']) {
    $productsQuery->post_count = min($arguments['maxResultsNumber'], $productsQuery->post_count);
    $productsQuery->found_posts = min($arguments['maxResultsNumber'], $productsQuery->found_posts);
}

$arguments['productsQuery'] = $productsQuery;

echo '<section class="wcsf-products woocommerce">';

if (in_array($arguments['mode'], ['single-step', 'sequence'])) {
    Template::html('controls/index', $arguments);

    if ($arguments['enableValue']) {
        Template::html('value', $arguments);
    }
}

if ($productsQuery->have_posts()) {
    if ($arguments['resultsBeforeProductsDescription']) {
        echo '<div class="wcsf-products-description is-top">'
            . do_shortcode(wpautop($arguments['resultsBeforeProductsDescription'])) . '</div>';
    }

    echo '<div class="wcsf-products-controls clearfix">';

    Template::html('products/order-by', $arguments);
    Template::html('products/result-count', $arguments);

    echo '</div>';

    woocommerce_product_loop_start();

    while ($productsQuery->have_posts()) {
        $productsQuery->the_post();

        do_action('woocommerce_shop_loop');
        wc_get_template_part('content', 'product');
    }

    woocommerce_product_loop_end();

    Template::html('products/pagination', $arguments);

    if ($arguments['resultsAfterProductsDescription']) {
        echo '<div class="wcsf-products-description is-bottom">'
            . do_shortcode(wpautop($arguments['resultsAfterProductsDescription'])) . '</div>';
    }
} else {
    if ($arguments['resultsBeforeNoProductsDescription']) {
        echo '<div class="wcsf-products-no-results-description is-top">'
            . do_shortcode(wpautop($arguments['resultsBeforeNoProductsDescription'])) . '</div>';
    }

    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');

    if ($arguments['resultsAfterNoProductsDescription']) {
        echo '<div class="wcsf-products-no-results-description is-bottom">'
            . do_shortcode(wpautop($arguments['resultsAfterNoProductsDescription'])) . '</div>';
    }
}

echo '</section>';

$productsQuery->reset_postdata();
wp_reset_postdata();
wp_reset_query();
