<?php
defined('ABSPATH') || exit;

use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'formId' => null,
    'extraQueryArgs' => [
        'orderby' => isset($_REQUEST['orderby'])
            ? wc_clean(wp_unslash($_REQUEST['orderby']))
            : apply_filters('woocommerce_default_catalog_orderby', get_option('woocommerce_default_catalog_orderby'))
    ]
]);

$orderByOptions = apply_filters(
    'woocommerce_catalog_orderby',
    [
        'menu_order' => esc_html__('Default sorting', 'woocommerce'),
        'popularity' => esc_html__('Sort by popularity', 'woocommerce'),
        'rating' => esc_html__('Sort by average rating', 'woocommerce'),
        'date' => esc_html__('Sort by newness', 'woocommerce'),
        'price' => esc_html__('Sort by price: low to high', 'woocommerce'),
        'price-desc' => esc_html__('Sort by price: high to low', 'woocommerce')
    ]
);

if ('no' === get_option('woocommerce_enable_review_rating')) {
    unset($orderByOptions['rating']);
}

if (is_array($orderByOptions) && !array_key_exists((string) $arguments['extraQueryArgs']['orderby'], $orderByOptions)) {
    $arguments['extraQueryArgs']['orderby'] = current(array_keys($orderByOptions));
}
?>
<div class="wcsf-products-ordering woocommerce-ordering" data-component="wcsf-ordering">
    <select name="orderby" class="wcsf-products-ordering-value"
        aria-label="<?php esc_attr_e('Shop order', 'woocommerce'); ?>"
        form="<?php echo esc_attr($arguments['formId']); ?>"
        data-component="wcsf-ordering-select">
        <?php foreach ($orderByOptions as $optionId => $optionName) { ?>
            <option value="<?php echo esc_attr($optionId); ?>"<?php
                selected($arguments['extraQueryArgs']['orderby'], $optionId);
                ?>><?php echo esc_html($optionName); ?></option>
        <?php } ?>
    </select>
    <noscript>
        <button type="submit" class="wcsf-products-ordering-submit btn btn-secondary btn-sm"
            form="<?php echo esc_attr($arguments['formId']); ?>"><?php
            esc_html_e('Apply order', 'woocommerce-step-filter');
            ?></button>
    </noscript>
</div>
