<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\PDF;
use \WCStepFilter\Template;
use \WCStepFilter\Utils;

$arguments = Template::getHTMLArgs(
    [
        'resultsPDFHeaderContent' => Filter::getSetting($id, 'results_pdf_header_content'),
        'resultsPDFHeaderHeight' => Filter::getSetting($id, 'results_pdf_header_height'),
        'resultsPDFFooterContent' => Filter::getSetting($id, 'results_pdf_footer_content'),
        'resultsPDFFooterHeight' => Filter::getSetting($id, 'results_pdf_footer_height'),
        'resultsPDFTopDescription' => Filter::getSetting($id, 'results_pdf_top_description'),
        'resultsPDFBottomDescription' => Filter::getSetting($id, 'results_pdf_bottom_description'),
        'resultsPDFProductsColumns' => Filter::getSetting($id, 'results_pdf_products_columns', wc_get_loop_prop('columns')),
        'resultsPDFAdditionalCSS' => Filter::getSetting($id, 'results_pdf_additional_css'),
        'maxResultsNumber' => Filter::getSetting($id, 'max_results_number'),
        'enableValue' => Filter::getSetting($id, 'enable_value'),
        'formData' => [],
        'wizardArguments' => [],
        'extraQueryArgs' => [
            'post__in' => [],
            'posts_per_page' => Filter::getSetting(
                $id,
                'results_pdf_products_number',
                wc_get_default_products_per_row() * wc_get_default_product_rows_per_page()
            )
        ],
    ],
    ['recursive' => true]
);

$productsQueryArgs = Filter::getProductsQueryArgs($id, $arguments['extraQueryArgs']);
?>
<style>
    @page {
        size: A4;
        margin: <?php
        // phpcs:disable
        echo ($arguments['resultsPDFHeaderHeight'] + 1) . 'cm 1.5cm ' . ($arguments['resultsPDFFooterHeight'] + 1) . 'cm';
        // phpcs:enable
        ?>;
    }

    body {
        font-family: DejaVu Sans, sans-serif;
    }

    .header,
    .footer {
        position: fixed;
        left: -1.5cm;
        right: -1.5cm;
        width: 21cm;
    }

    .header {
        top: <?php echo '-' . ($arguments['resultsPDFHeaderHeight'] + 1) . 'cm'; ?>;
        height: <?php echo "{$arguments['resultsPDFHeaderHeight']}cm"; ?>;
    }

    .footer {
        bottom: <?php echo '-' . ($arguments['resultsPDFFooterHeight'] + 1) . 'cm'; ?>;
        height: <?php echo "{$arguments['resultsPDFFooterHeight']}cm"; ?>;
    }

    .description {
        clear: both;
    }

    .page-number::after {
        content: counter(page);
    }

    .new-page {
        page-break-after: always;
    }

    .products {
        width: 100%;
        border-collapse: separate;
        border-spacing: 0.5em;
        table-layout: fixed;
    }

    .product {
        page-break-inside: avoid;
        margin-bottom: 1em;
    }

    .product-title {
        margin-bottom: 0.5em;
        font-weight: normal;
        font-size: 1.1em;
        line-height: 1;
    }

    .product-title-link {
        font-weight: bolder;
        text-decoration: none;
        color: inherit;
    }

    .product-thumbnail {
        display: block;
        width: 100%;
        height: auto;
    }

    .product-thumbnail-link {
        display: block;
        padding: 0.25em;
        border: 1px solid #ccc;
        border-radius: 0.15em;
    }

    .product-price {
        margin-bottom: 1em;
        font-weight: normal;
    }

    .wcsf-value-item-remove {
        display: none;
    }

    td,
    th {
        vertical-align: top;
    }

    <?php echo $arguments['resultsPDFAdditionalCSS']; ?>
</style>
<div class="header"><div class="header-inner"><?php
    echo PDF::prepareContent($arguments['resultsPDFHeaderContent'], $arguments['formData']);
    ?></div></div>
<div class="footer"><div class="footer-inner"><?php
    echo PDF::prepareContent($arguments['resultsPDFFooterContent'], $arguments['formData']);
    ?></div></div>
<div class="description is-top"><?php
    echo PDF::prepareContent($arguments['resultsPDFTopDescription'], $arguments['formData']);
    ?></div>
<?php
if (!empty($arguments['wizardArguments']) && class_exists('\WCProductsWizard\Product')) {
    $productsQueryArgs['post__in'] = array_replace(
        (array) $arguments['extraQueryArgs']['post__in'],
        \WCProductsWizard\Product::getStepProductsIds(
            $arguments['wizardArguments']['id'],
            $arguments['wizardArguments']['stepId'],
            ['queryArgs' => $productsQueryArgs]
        )
    );
}

$productsQuery = new \WP_Query($productsQueryArgs);

do_action('wcsf_products_query', $id, $arguments, $productsQuery);

// change max products count
if ($arguments['maxResultsNumber']) {
    $productsQuery->post_count = min($arguments['maxResultsNumber'], $productsQuery->post_count);
    $productsQuery->found_posts = min($arguments['maxResultsNumber'], $productsQuery->found_posts);
}

$arguments['productsQuery'] = $productsQuery;

echo '<div class="woocommerce">';

if ($arguments['enableValue']) {
    Template::html('value', $arguments);
}

if ($productsQuery->have_posts()) {
    $loop = 1;
    $columns = $arguments['resultsPDFProductsColumns']
        ? $arguments['resultsPDFProductsColumns']
        : wc_get_loop_prop('columns');

    $width = round(100 / max(1, $columns), 3);

    echo '<table class="products"><tr>';

    while ($productsQuery->have_posts()) {
        $productsQuery->the_post();

        global $product;

        if (!$product instanceof \WC_Product) {
            continue;
        }
        ?>
        <td width="<?php echo $width; ?>%;">
            <div class="product">
                <?php
                $imageId = $product->get_image_id()
                    ? $product->get_image_id()
                    : get_option('woocommerce_placeholder_image', 0);

                if ($imageId) {
                    ?>
                    <a class="product-thumbnail-link" href="<?php
                        if (method_exists($product, 'get_permalink')) {
                            echo $product->get_permalink();
                        }
                        ?>"><?php
                        echo Utils::replaceImagesToBase64InHtml(wp_get_attachment_image(
                            $imageId,
                            'shop_catalog',
                            false,
                            [
                                'class' => 'product-thumbnail',
                                'width' => '80'
                            ]
                        ));
                        ?></a>
                    <?php
                }
                ?>
                <h3 class="product-title">
                    <a class="product-title-link" href="<?php
                    if (method_exists($product, 'get_permalink')) {
                        echo $product->get_permalink();
                    }
                    ?>"><?php
                        if (method_exists($product, 'get_name')) {
                            echo $product->get_name();
                        }
                        ?></a>
                </h3>
                <div class="product-price"><?php echo wc_price($product->get_price()); ?></div>
            </div>
        </td>
        <?php
        if ($loop++ == $columns) {
            $loop = 1;

            echo '</tr><tr>';
        }
    }

    echo '</tr></table>';
} else {
    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');
}

echo '</div>';
?>
<div class="description is-bottom"><?php
    echo PDF::prepareContent($arguments['resultsPDFBottomDescription'], $arguments['formData']);
    ?></div>
