<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Question;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'step' => Filter::getActiveStep($id),
    'filterValue' => Filter::getValue($id),
    'mode' => 'single-step',
    'activeStepId' => null,
    'extraQueryArgs' => []
]);

$step = $arguments['step'];
$class = ['wcsf-step', 'is-step-id-' . $step->id];

if (Filter::getActiveStepId($id) == $step->id) {
    $class[] = 'is-active';
}

if (isset($arguments['filterValue'][$step->id])) {
    $class[] = 'has-value';
}

\WCStepFilter\Instance()->question->setCurrentId($step->id);
?>
<article class="<?php echo esc_attr(implode(' ', $class)); ?>"
    data-component="wcsf-step" data-id="<?php echo esc_attr($step->id); ?>">
    <?php
    if ($step->id == 'results') {
        Template::html('products/index', $arguments);
    } else {
        foreach (\WCStepFilter\Instance()->filter->getNotices($step->id) as $notice) {
            Template::html('message', array_replace($arguments, $notice));
        }

        Template::html('description', array_replace($arguments, ['description' => $step->description]));

        if (property_exists($step, 'children')) {
            $class = ['is-layout-' . $step->layout];

            if ($step->layout == 'grid') {
                $class[] = 'row';
                $gridColumns = $step->gridColumns;

                if (!isset($gridColumns['xxs'])) {
                    $gridColumns['xxs'] = 12;
                }

                $class[] = "row-cols-{$gridColumns['xxs']}";

                unset($gridColumns['xxs']);

                foreach ($gridColumns as $col => $value) {
                    $class[] = "row-cols-{$col}-{$value}";
                }
            }

            echo '<div class="wcsf-step-fields ' . esc_attr(implode(' ', $class)) . '">';

            foreach ($step->children as $question) {
                $class = ['is-question-' . $question->id];

                if ($question->hasValue) {
                    $class[] = 'has-value';
                }

                if ($step->layout == 'grid') {
                    $class[] = 'col';
                }

                foreach (\WCStepFilter\Instance()->filter->getNotices($question->id) as $notice) {
                    Template::html('message', array_replace($arguments, $notice));
                }

                $childArguments = array_replace(
                    $arguments,
                    [
                        'question' => $question,
                        'description' => $question->description,
                        'fields' => Question::getFields($id, $question->id, $arguments['extraQueryArgs'])
                    ]
                );

                \WCStepFilter\Instance()->question->setCurrentId($question->id);

                echo '<section class="wcsf-step-field ' . esc_attr(implode(' ', $class)) . '">';

                Template::html('description', $childArguments);
                Template::html('fields/index', $childArguments);

                echo '</section>';
            }

            echo '</div>';
        } else {
            Template::html(
                'fields/index',
                array_replace(
                    $arguments,
                    [
                        'question' => $step,
                        'fields' => Question::getFields($id, $step->id, $arguments['extraQueryArgs'])
                    ]
                )
            );
        }
    }
    ?>
</article>
