<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'id' => $id,
    'showResultsWithin' => Filter::getSetting($id, 'show_results_within'),
    'valueList' => Filter::getValueList($id),
    'mode' => Filter::getSetting($id, 'mode'),
    'resultsUrl' => Filter::getSetting($id, 'results_url')
]);

if (empty($arguments['valueList'])) {
    return;
}
?>
<ul class="wcsf-value">
    <?php foreach ($arguments['valueList'] as $item) { ?>
        <li class="wcsf-value-item">
            <?php if (in_array($arguments['mode'], ['step-by-step', 'sequence'])) { ?>
                <span class="wcsf-value-item-check"></span>
            <?php } else { ?>
                <a href="<?php echo esc_url(Filter::getResetValueUrl($arguments['id'], $item->id)); ?>"
                    role="button"
                    class="wcsf-value-item-remove"
                    data-component="<?php
                    echo $arguments['resultsUrl'] == '#' && !$arguments['showResultsWithin']
                        ? 'none'
                        : 'wcsf-value-item-remove';
                    ?>"
                    data-id="<?php echo esc_attr($item->id); ?>">
                    <span class="sr-only visually-hidden"><?php
                        esc_html_e('Remove', 'woocommerce-step-filter');
                        ?></span>
                </a>
            <?php } ?>
            <!--spacer-->
            <span class="wcsf-value-item-name"><?php echo wp_kses_post($item->name); ?>:</span>
            <!--spacer-->
            <span class="wcsf-value-item-value"><?php echo wp_kses_post($item->value); ?></span>
        </li>
    <?php } ?>
</ul>
